@@ -104,9 +104,9 @@ class App:
             if debug == "true":
                 application.config["DEBUG"] = True
                 application.config["ENV"] = "development"
-                application.run(host='0.0.0.0', port=port)
+                application.run(host='localhost', port=port)
             else:
-                application.run(host='0.0.0.0', port=port)
+                application.run(host="localhost", port=port)
 
         except ExecutorException as e:
             raise ExecutorException(status=e.status, reason=e.reason)
